@@ -42,7 +42,7 @@ def cli(token=None):
     global client
     _token = token or _find_token()
     if _token is None:
-        sys.exit('Token is missed')
+        sys.exit('Token is missed, please see doc: https://docs.featurize.cn/命令行工具')
 
     client = FeaturizeClient(token=_token)
 
@@ -66,10 +66,9 @@ def ls(raw=False):
 
 @instance.command()
 @click.argument('instance_id')
-@click.option('-t', '--term', type=click.Choice(['daily', 'weekly', 'monthly'], case_sensitive=False))
-def request(instance_id, term):
+def request(instance_id):
     try:
-        client.instance.request(instance_id, term)
+        client.instance.request(instance_id)
     except ServiceError as e:
         if e.code == 10015:
             sys.exit('Error: requested instance is busy.')
@@ -97,6 +96,21 @@ def release(instance_id):
     print('Successfully released instance.')
 
 
+@cli.group()
+def notebook():
+    pass
+
+@notebook.command()
+@click.argument('file')
+@click.option('-n', '--name', required=True)
+def create(file: str, name: str):
+    try:
+        response = client.notebook.create(file, name)
+    except Exception as e:
+        sys.exit(f'Uncaught error {e}')
+    print(f'Successfully created public notebook, visit https://featurize.cn/notebooks/{response["digest"]}')
+
+
 @cli.group()
 def dataset():
     pass
@@ -107,7 +121,13 @@ def dataset():
 @click.option('-n', '--name', default='')
 @click.option('-r', '--range', type=Choice(['public', 'personal']), default='personal')
 @click.option('-d', '--description', default='')
-def upload(file, name, range, description):
+@click.option('-d', '--proxy', is_flag=True, default=False)
+def upload(file, name, range, description, proxy):
+    if not proxy:
+        os.environ['HTTP_PROXY'] = ''
+        os.environ['HTTPS_PROXY'] = ''
+        os.environ['http_proxy'] = ''
+        os.environ['https_proxy'] = ''
     if not (file.endswith(".zip") or file.endswith(".tar.gz")):
         sys.exit('Error: uploading file should be one of .zip or .tar.gz type')
     filepath = Path(file)
